===========
SymPy 0.5.3
===========

8 Sep 2007

* Faster import sympy statement.
* Using the ``integrate(3*t**2, (t, 0, x))`` syntax again (as was in the 0.4.3 version).
* Using true division in isympy (``1/2`` returns ``0.5`` instead of ``0``, example).
* Plotting module can save images.
* Implemented extended Risch-Norman heuristic.
* Full partial fraction decomposition via ``apart()``.
* Added a complete set of rewrite rules for trigonometric and hyperbolic functions.
* ComplexInfinity renamed to ``zoo``.
